================
trialbureautools
================


.. image:: https://img.shields.io/pypi/v/trialbureautools.svg
        :target: https://pypi.python.org/pypi/trialbureautools

.. image:: https://img.shields.io/travis/sjoerdk/trialbureautools.svg
        :target: https://travis-ci.org/sjoerdk/trialbureautools

.. image:: https://readthedocs.org/projects/trialbureautools/badge/?version=latest
        :target: https://trialbureautools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/sjoerdk/trialbureautools/shield.svg
     :target: https://pyup.io/repos/github/sjoerdk/trialbureautools/
     :alt: Updates



Command line utilities for the radboudumc trial bureau


* Free software: MIT license
* Documentation: https://trialbureautools.readthedocs.io.


Features
--------

* Set folder permissions

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
